"use strict";

var _react = require("@testing-library/react");
var _vitest = require("vitest");
require("@testing-library/jest-dom");
var _index = require("../index");
var _index2 = require("../../index");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

describe('<DrawerTray />', () => {
  it('should render tray content when open', async () => {
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.DrawerTray, {
      label: "DrawerTray Example",
      open: true,
      render: () => {
        return 'Hello from layout tray';
      }
    }));
    const drawerTray = _react.screen.getByLabelText('DrawerTray Example');
    expect(drawerTray).toBeInTheDocument();
    expect(drawerTray).toHaveTextContent('Hello from layout tray');
  });
  it('should call the contentRef', async () => {
    const contentRef = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.DrawerTray, {
      label: "DrawerTray Example",
      open: true,
      contentRef: contentRef,
      render: () => {
        return 'Hello from layout tray';
      }
    }));
    const drawerTray = _react.screen.getByLabelText('DrawerTray Example');
    expect(contentRef).toHaveBeenCalledWith(drawerTray.parentElement);
  });
  it('should call onOpen', async () => {
    const onOpen = _vitest.vi.fn();
    const _render = (0, _react.render)((0, _jsxRuntime.jsx)(_index.DrawerTray, {
        label: "DrawerTray Example",
        open: false,
        onOpen: onOpen,
        render: () => {
          return 'Hello from layout tray';
        }
      })),
      rerender = _render.rerender;
    expect(onOpen).not.toHaveBeenCalled();

    // set prop open
    rerender((0, _jsxRuntime.jsx)(_index.DrawerTray, {
      label: "DrawerTray Example",
      open: true,
      onOpen: onOpen,
      render: () => {
        return 'Hello from layout tray';
      }
    }));
    await (0, _react.waitFor)(() => {
      expect(onOpen).toHaveBeenCalled();
    });
  });
  it('should call onOpen when open initially', async () => {
    const onOpen = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.DrawerTray, {
      label: "DrawerTray Example",
      open: true,
      onOpen: onOpen,
      render: () => {
        return 'Hello from layout tray';
      }
    }));
    await (0, _react.waitFor)(() => {
      expect(onOpen).toHaveBeenCalled();
    });
  });
  it('should call onClose', async () => {
    const onClose = _vitest.vi.fn();
    const _render2 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.DrawerTray, {
        label: "DrawerTray Example",
        open: true,
        onClose: onClose,
        render: () => {
          return 'Hello from layout tray';
        }
      })),
      rerender = _render2.rerender;
    expect(onClose).not.toHaveBeenCalled();

    // set prop open
    rerender((0, _jsxRuntime.jsx)(_index.DrawerTray, {
      label: "DrawerTray Example",
      open: false,
      onClose: onClose,
      render: () => {
        return 'Hello from layout tray';
      }
    }));
    await (0, _react.waitFor)(() => {
      expect(onClose).toHaveBeenCalled();
    });
  });
  describe('should apply the a11y attributes', () => {
    it("when it doesn't overlay the content", async () => {
      (0, _react.render)((0, _jsxRuntime.jsx)(_index2.DrawerLayoutContext.Provider, {
        value: false,
        children: (0, _jsxRuntime.jsx)(_index.DrawerTray, {
          label: "a tray test",
          open: true,
          render: () => {
            return 'Hello from layout tray';
          }
        })
      }));
      const drawerTray = _react.screen.getByLabelText('a tray test');
      expect(drawerTray).toBeInTheDocument();
      expect(drawerTray).toHaveAttribute('role', 'region');
    });
    it('when it overlays the content', async () => {
      (0, _react.render)((0, _jsxRuntime.jsx)(_index2.DrawerLayoutContext.Provider, {
        value: true,
        children: (0, _jsxRuntime.jsx)(_index.DrawerTray, {
          label: "a tray test",
          open: true,
          render: () => {
            return 'Hello from layout tray';
          }
        })
      }));
      const drawerTray = _react.screen.getByLabelText('a tray test');
      expect(drawerTray).toBeInTheDocument();
      expect(drawerTray).toHaveAttribute('role', 'dialog');
    });
  });
});