import React from 'react';
import type { PositionMountNode } from '@instructure/ui-position';
import type { TextDirectionContextConsumerProps } from '@instructure/ui-i18n';
import type { ComponentStyle, WithStyleProps } from '@instructure/emotion';
import type { DrawerLayoutTrayTheme, LiveRegion, OtherHTMLAttributes, PropValidators, UIElement } from '@instructure/shared-types';
import { BaseTransitionStatesType, TransitionType } from '@instructure/ui-motion/src/Transition/BaseTransition/props';
type DrawerTrayPlacement = 'start' | 'end';
type DrawerLayoutTrayOwnProps = {
    label: string;
    children?: React.ReactNode | (() => React.ReactNode);
    render?: () => React.ReactNode;
    /**
     * Placement of the `<DrawerLayout.Tray />`
     */
    placement?: DrawerTrayPlacement;
    /**
     * If the tray is open or closed.
     */
    open?: boolean;
    /**
     * Called when the `<DrawerLayout.Tray />` is opened
     */
    onOpen?: (transitionType?: TransitionType) => void;
    /**
     * Called when the `<DrawerLayout.Tray />` is closed
     */
    onClose?: (transitionType?: TransitionType) => void;
    /**
     * Should the `<DrawerLayout.Tray />` have a border
     */
    border?: boolean;
    /**
     * Should the `<DrawerLayout.Tray />` have a shadow
     */
    shadow?: boolean;
    /**
     * Ref function for the `<DrawerLayout.Tray />` content
     */
    contentRef?: (element: HTMLDivElement | null) => void;
    /**
     * An element or a function returning an element to use as the mount node
     * for the `<DrawerLayout.Tray />` when tray is overlaying content
     */
    mountNode?: PositionMountNode;
} & PropsPassedToDialog & PropsPassedToTransition & TextDirectionContextConsumerProps;
type PropsPassedToDialog = {
    /**
     * An element or a function returning an element to focus by default
     */
    defaultFocusElement?: UIElement;
    /**
     * An element, function returning an element, or array of elements that will not be hidden from
     * the screen reader when the `<DrawerLayout.Tray />` is open
     */
    liveRegion?: LiveRegion;
    onDismiss?: (event: React.UIEvent | React.FocusEvent, documentClick?: boolean) => void;
    shouldContainFocus?: boolean;
    shouldReturnFocus?: boolean;
    shouldCloseOnDocumentClick?: boolean;
    shouldCloseOnEscape?: boolean;
};
type PropsPassedToTransition = {
    /**
     * Callback fired when the `<DrawerLayout.Tray />` transitions in/out
     */
    onTransition?: (toState: BaseTransitionStatesType, fromState: BaseTransitionStatesType) => void;
    /**
     * Callback fired before the `<DrawerLayout.Tray />` transitions in
     */
    onEnter?: () => void;
    /**
     * Callback fired as the `<DrawerLayout.Tray />` begins to transition in
     */
    onEntering?: () => void;
    /**
     * Callback fired after the `<DrawerLayout.Tray />` finishes transitioning in
     */
    onEntered?: (type?: TransitionType) => void;
    /**
     * Callback fired right before the `<DrawerLayout.Tray />` transitions out
     */
    onExit?: () => void;
    /**
     * Callback fired as the `<DrawerLayout.Tray />` begins to transition out
     */
    onExiting?: () => void;
    /**
     * Callback fired after the `<DrawerLayout.Tray />` finishes transitioning out
     */
    onExited?: (type?: TransitionType) => void;
};
type DrawerLayoutTrayState = {
    transitioning: boolean;
    portalOpen: boolean;
};
type DrawerLayoutTrayStyleProps = {
    placement: DrawerTrayPlacement;
};
type PropKeys = keyof DrawerLayoutTrayOwnProps;
type AllowedPropKeys = Readonly<Array<PropKeys>>;
type DrawerLayoutTrayProps = DrawerLayoutTrayOwnProps & WithStyleProps<DrawerLayoutTrayTheme, DrawerLayoutTrayStyle> & OtherHTMLAttributes<DrawerLayoutTrayOwnProps>;
type DrawerLayoutTrayStyle = ComponentStyle<'drawerTray' | 'drawerTrayWithShadow' | 'drawerTrayContent'>;
declare const propTypes: PropValidators<PropKeys>;
declare const allowedProps: AllowedPropKeys;
export type { DrawerLayoutTrayProps, DrawerLayoutTrayState, DrawerLayoutTrayStyle, DrawerLayoutTrayStyleProps, DrawerTrayPlacement };
export { allowedProps, propTypes };
//# sourceMappingURL=props.d.ts.map