import React from 'react';
import type { TextDirectionContextConsumerProps } from '@instructure/ui-i18n';
import type { WithStyleProps, ComponentStyle } from '@instructure/emotion';
import type { PropValidators } from '@instructure/shared-types';
import type { WithDeterministicIdProps } from '@instructure/ui-react-utils';
type DrawerLayoutOwnProps = {
    /**
     * Exactly one of each of the following child types: `DrawerLayout.Content`, `DrawerLayout.Tray`
     */
    children?: React.ReactNode;
    /**
     * Min width for the `<DrawerLayout.Content />`
     */
    minWidth?: string;
    /**
     * Function called when the `<DrawerLayout.Content />` is resized and hits the `minWidth` breakpoint
     * Called with a boolean value, `true` if the tray is now overlaying the content or `false` if
     * it is side by side
     */
    onOverlayTrayChange?: (shouldOverlayTray: boolean) => void;
} & TextDirectionContextConsumerProps;
type PropKeys = keyof DrawerLayoutOwnProps;
type AllowedPropKeys = Readonly<Array<PropKeys>>;
type DrawerLayoutProps = DrawerLayoutOwnProps & WithStyleProps<null, DrawerLayoutStyle> & WithDeterministicIdProps;
type DrawerLayoutStyle = ComponentStyle<'drawerLayout'>;
type DrawerLayoutState = {
    shouldOverlayTray: boolean;
    trayWidth: number;
    contentWidth: number;
};
declare const propTypes: PropValidators<PropKeys>;
declare const allowedProps: AllowedPropKeys;
export type { DrawerLayoutProps, DrawerLayoutState, DrawerLayoutStyle };
export { propTypes, allowedProps };
//# sourceMappingURL=props.d.ts.map